import * as yargs from "yargs";
import { generator, getConfig } from "css-var-extract";
import path from "node:path";
import chokidar from "chokidar";
const generate = async (nocreate) => {
  try {
    await generator(getConfig(nocreate));
    process.exit(0);
  } catch (err) {
    console.error(err);
    process.exit(1);
  }
};
const watch = async (nocreate) => {
  const configWatcher = chokidar.watch(
    path.resolve(process.cwd(), "cve.config.json")
  );
  let watcher = new chokidar.FSWatcher({});
  const generatorWatcher = () => {
    const config = getConfig();
    watcher.close();
    console.info(`CVE: Watching files (${config.files})...`);
    watcher = chokidar.watch(config.files);
    watcher.on("ready", async () => {
      const handle = async () => {
        try {
          await generator(config);
        } catch (err) {
          console.error(err);
          console.info();
        }
      };
      await handle();
      let timeout;
      const deduped = (_file) => {
        if (timeout) {
          clearTimeout(timeout);
        }
        timeout = setTimeout(handle, 10);
      };
      watcher.on("change", deduped);
      watcher.on("add", deduped);
      watcher.on("unlink", deduped);
    });
  };
  configWatcher.on("ready", generatorWatcher);
  configWatcher.on("change", generatorWatcher);
};
main();
function main() {
  yargs.scriptName("cve").usage("$0 <cmd> [args]").command(
    "generate",
    "Generate the .ts file from CSS files",
    (yargs2) => yargs2.option("nocreate", {
      describe: "Disable the creation of a config file",
      type: "boolean"
    }),
    async ({ nocreate }) => generate(nocreate)
  ).command(
    "watch",
    "Continuously watch and generate the .ts file from CSS files",
    (yargs2) => yargs2.option("nocreate", {
      describe: "Disable the creation of a config file",
      type: "boolean"
    }),
    async ({ nocreate }) => watch()
  ).strict().demandCommand(1).parse();
}
export {
  main
};
//# sourceMappingURL=index.js.map
